Reverse sense of unwind-tables option.  This means
stack tracebacks on Darwin x86-64 won't work by default;
nevertheless, everybody but me thinks this is a good idea.



git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@49663 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/DwarfWriter.cpp b/lib/CodeGen/DwarfWriter.cpp
index 6cdc91e..3a3a04d 100644
--- a/lib/CodeGen/DwarfWriter.cpp
+++ b/lib/CodeGen/DwarfWriter.cpp
@@ -2906,10 +2906,10 @@
     // If there are no calls then you can't unwind.  This may mean we can
     // omit the EH Frame, but some environments do not handle weak absolute
     // symbols.  
     // If UnwindTablesOptional is not set we cannot do this optimization; the
     // unwind info is to be available for non-EH uses.
     if (!EHFrameInfo.hasCalls &&
-        UnwindTablesOptional &&
+        !UnwindTablesMandatory &&
         ((linkage != Function::WeakLinkage && 
           linkage != Function::LinkOnceLinkage) ||
          !TAI->getWeakDefDirective() ||
@@ -3432,7 +3432,7 @@
       // See if we need frame move info.
       if (MMI->hasDebugInfo() || 
           !MF->getFunction()->doesNotThrow() ||
-          !UnwindTablesOptional)
+          UnwindTablesMandatory)
         shouldEmitMoves = true;
 
       if (shouldEmitMoves || shouldEmitTable)
@@ -2906,10 +2906,10 @@
     // omit the EH Frame, but some environments do not handle weak absolute
     // symbols.  
-    // If UnwindTablesOptional is not set we cannot do this optimization; the
+    // If UnwindTablesMandatory is set we cannot do this optimization; the
     // unwind info is to be available for non-EH uses.
     if (!EHFrameInfo.hasCalls &&